@@ -35,9 +35,9 @@
 #' @param pcor_method a character string indicating which partial correlation
 #' coefficient is to be computed. One of "pearson" (default), "kendall", or
 #' "spearman", can be abbreviated.
-#' @param previous_year if set to TRUE, env_data and response variables will be
-#' rearranged in a way, that also previous year will be used for calculations of
-#' selected statistical metric.
+#' @param previous_year if set to TRUE, env_data_primary, env_data_control  and
+#' response variables will be rearranged in a way, that also previous year will
+#' be used for calculations of selected statistical metric.
 #' @param remove_insignificant if set to TRUE, removes all correlations bellow
 #' the significant threshold level, based on a selected alpha.
 #' @param alpha significance level used to remove insignificant calculations.
@@ -113,6 +113,10 @@
 #' "perc", "bca").
 #' @param boot_conf_int A scalar or vector containing the confidence level(s) of
 #' the required interval(s)
+#' @param day_interval a vector of two values: lower and upper time interval of
+#' days that will be used to calculate statistical metrics. Negative values
+#' indicate previous growing season days. This argument overwrites the calculation
+#' limits defined by lower_limit and upper_limit arguments.
 #'
 #' @return a list with 15 elements:
 #' \enumerate{
@@ -210,8 +214,98 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
                            ylimits = NULL, seed = NULL, tidy_env_data_primary = FALSE,
                            tidy_env_data_control = FALSE,
                            reference_window = 'start',  boot = FALSE, boot_n = 1000,
-                           boot_ci_type = "norm", boot_conf_int = 0.95) {
+                           boot_ci_type = "norm", boot_conf_int = 0.95,
+                           day_interval = ifelse(c(previous_year == TRUE,
+                                                   previous_year == TRUE),
+                                                 c(-1, 366), c(1, 366))
+                           ) {
 
+  ##############################################################################
+  # 1 day interval is organized
+  offset_start <- day_interval[1]
+  offset_end <- day_interval[2]
+
+  # if both are positive but previous_year = TRUE
+  if (offset_start > 0 & offset_end > 0 & previous_year == TRUE){
+
+    previous_year <- FALSE
+
+    warning(paste0("Previous year is not included in selected day_interval. ",
+                   "The argument previous_year is set to FALSE"))
+  }
+
+
+  # if both are negative negative
+  if (offset_start < 0 & offset_end < 0){
+    offset_start <- abs(offset_start)
+    offset_end <- abs(offset_end)
+
+    # If previous_year is FALSE, we set it to TRUE
+    if (previous_year == FALSE){
+      previous_year = TRUE
+      warning(paste0("Previous year is included in day_interval. ",
+                     "The argument previous_year is set to TRUE"))
+    }
+
+    # if only offset_start is negative
+  } else if (offset_start < 0 & offset_end > 0){
+    offset_end <- offset_end + 366
+    offset_start <- abs(offset_start)
+
+    # If previous_year is FALSE, we set it to TRUE
+    if (previous_year == FALSE){
+      previous_year = TRUE
+      warning(paste0("Previous year is included in day_interval. ",
+                     "The argument previous_year is set to TRUE"))
+    }
+
+  }
+
+  # Calculate the max_window allowed
+  max_window <- offset_end - offset_start + 1
+
+  # If max_window is greater then upper_limit, it must be reduced
+  if (upper_limit > max_window){
+
+    upper_limit <- max_window
+
+    if (fixed_width == 0){
+    warning(paste0("The upper_limit is outside your day_interval and",
+                   " therefore reduced to the maximum allowed: ",max_window,"."))
+    }
+  }
+
+  # Now, if upper_limit > max_window, we make them the same
+  if (lower_limit > max_window){
+
+    lower_limit <- max_window
+
+    if (fixed_width == 0){
+    warning(paste0("The lower_limit is outside your day_interval and",
+                   " therefore reduced to the minimum allowed: ",max_window,"."))
+    }
+  }
+
+
+  # Also correction for fixed_window approach
+  if (fixed_width > max_window){
+
+    stop(paste0("The selected fixed_width is outside your day_interval.",
+                " Decrease the fixed_width argument to at least: ",max_window,"."))
+  }
+
+
+  if (previous_year == FALSE){
+
+    offset_end <- 366 - offset_end
+
+  } else {
+
+    offset_end <- 732 - offset_end
+
+  }
+
+  ##############################################################################
 
   if (!is.null(seed)) {
     set.seed(seed)
@@ -340,25 +434,41 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
   if (nrow(response) !=  nrow(env_data_primary) & row_names_subset == FALSE)
     stop("Length of env_data_primary and response records differ")
 
-  # Stop message if fixed_width is not between 0 and 365
-  if (fixed_width < 0 | fixed_width > 365)
-    stop("fixed_width should be between 0 and 365")
+  #######################################################
+  # Rules for previous_year = FALSE
 
-  # Stop in case of method == "cor" and ncol(proxies) > 1
-  # Correlations could be calculated only for one variable
-  if (method == "cor" & ncol(response) > 1)
-    stop(paste("More than 1 variable in response data frame not suitable ",
-  "for 'pcor' method'"))
+  if (previous_year == FALSE){
 
-  if (lower_limit >= upper_limit)
-    stop("lower_limit can not be higher than upper_limit!")
+    # Stop message if fixed_width is not between 0 and 366
+    if (fixed_width < 0 | fixed_width > 366)
+      stop("fixed_width should be between 1 and 366")
 
-  if (lower_limit > 365 | lower_limit < 1)
-    stop("lower_limit out of bounds! It should be between 1 and 365")
+    if (lower_limit > upper_limit)
+      stop("lower_limit can not be higher than upper_limit!")
 
-  if (upper_limit > 365 | upper_limit < 1)
-    stop("upper_limit out of bounds! It should be between 1 and 365")
+    if (lower_limit > 366 | lower_limit < 1)
+      stop("lower_limit out of bounds! It should be between 1 and 366")
 
+    if (upper_limit > 366 | upper_limit < 1)
+      stop("upper_limit out of bounds! It should be between 1 and 366")
+
+    # Rules for previous_year = TRUE
+  } else if (previous_year == TRUE){
+
+    # Stop message if fixed_width is not between 0 and 366
+    if (fixed_width < 0 | fixed_width > 732)
+      stop("fixed_width should be between 1 and 732")
+
+    if (lower_limit > upper_limit)
+      stop("lower_limit can not be higher than upper_limit!")
+
+    if (lower_limit > 732 | lower_limit < 1)
+      stop("lower_limit out of bounds! It should be between 1 and 366")
+
+    if (upper_limit > 732 | upper_limit < 1)
+      stop("upper_limit out of bounds! It should be between 1 and 366")
+
+  }
 
   # Data manipulation
   # If use.previous == TRUE, env_data_primary data has to be rearranged accordingly
@@ -435,29 +545,17 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
                 "At least three characters needed!"))
   }
 
-  # In case of selected window size is less than 14 (2 weeks) or greater than 270 (9 months)
-  if (lower_limit < 14) {
-    warning("Selected lower_limit is less than 14. Consider increasing it!")
-  }
-
-  if (upper_limit > 270) {
-    warning("Selected upper_limit is greater than 270. Consider using lower upper_limit!")
-  }
-
-  if (fixed_width < 14 & fixed_width > 0) {
-    warning("Selected fixed_width is less than 14. Consider increasing it!")
-  }
-
-  if (fixed_width > 270) {
-    warning("Selected fixed_width is greater than 270. Consider using lower fixed_width!")
-  }
-
 
   # If PCA_transformation = TRUE, PCA is performed
   if (PCA_transformation == TRUE) {
 
     # Logarithmic transformation before PCA
     if (log_preprocess == TRUE) {
+
+      if (sum(response <= 0) > 1){
+        stop("your response data contains negative observations. Please set the argument log_preprocess to FALSE")
+      }
+
       response <- data.frame(log(response))
     }
 
@@ -501,11 +599,6 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
     subset_seq <- seq(lower_subset, upper_subset)
 
-
-
-
-
-
     if (any(!(subset_seq %in% row.names(response)))){
 
       stop(paste0("Undefined columns selected. Subset years don't exist",
@@ -525,19 +618,6 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     }
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
     response <- subset(response, row.names(response) %in% subset_seq)
     env_data_primary <- subset(env_data_primary, row.names(env_data_primary) %in% subset_seq)
     env_data_control <- subset(env_data_control, row.names(env_data_control) %in% subset_seq)
@@ -572,17 +652,19 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     temporal_matrix_upper <- temporal_matrix
 
 
-      pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width),
+    if (fixed_width != max_window){
+      pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1),
                            style = 3)
+    }
 
-      b = 0
+    b = 0
 
       # An iterating loop. In each itteration x is calculated and represents
       # response (dependent) variable. X is a moving average. Window width of
       # a moving window is fixed_width. Next, statistical metric is calculated
       # based on a selected method (cor, lm or brnn). Calculation is stored in
       # temporal matrix.
-      for (j in 0: (ncol(env_data_primary) - fixed_width)) {
+    for (j in (0 + offset_start -1): (ncol(env_data_primary) - max((fixed_width + offset_end), offset_end))) {
 
         b = b + 1
 
@@ -713,9 +795,9 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
           print(paste0("boot should be TRUE or FALSE, instead it is ", boot))
         }
 
-        setTxtProgressBar(pb, b)
+        if (fixed_width != max_window){setTxtProgressBar(pb, b)}
       }
-      close(pb)
+    if (fixed_width != max_window){close(pb)}
 
      # temporal_matrix is given rownames and colnames. Rownames represent a
      # window width used fot calculations. Colnames represent the position of
@@ -766,17 +848,19 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     temporal_matrix_lower <- temporal_matrix
     temporal_matrix_upper <- temporal_matrix
 
-  pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit),
-                       style = 3)
+    if (upper_limit != lower_limit){
 
-  b = 0
+      pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit), style = 3)
+    }
+
+    b = 0
 
 
   for (K in lower_limit:upper_limit) {
 
     b = b + 1
 
-    for (j in 0: (ncol(env_data_primary) - K)) {
+    for (j in (0 + offset_start -1): (ncol(env_data_primary) - max((K + offset_end), offset_end))) {
 
       if (aggregate_function_env_data_primary == 'median'){
 
@@ -933,10 +1017,10 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
       }
 
       }
-    setTxtProgressBar(pb, b)
+    if (upper_limit != lower_limit){setTxtProgressBar(pb, b)}
   }
 
-  close(pb)
+    if (upper_limit != lower_limit){close(pb)}
 
   # temporal_matrix is given rownames and colnames. Rownames represent a
   # window width used fot calculations. Colnames represent the position of
